@@ -2,24 +2,25 @@ package AnyEvent::Ident::Client;
 
 use strict;
 use warnings;
-use v5.10;
 use AnyEvent::Socket qw( tcp_connect );
 use AnyEvent::Handle;
 use Carp qw( carp );
 
 # ABSTRACT: Simple asynchronous ident client
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 
 sub new
 {
   my $class = shift;
   my $args     = ref $_[0] eq 'HASH' ? (\%{$_[0]}) : ({@_});
+  my $port = $args->{port};
+  $port = 113 unless defined $port;
   bless { 
-    hostname       => $args->{hostname}       // '127.0.0.1',  
-    port           => $args->{port}           // 113,
-    on_error       => $args->{on_error}       // sub { carp $_[0] },
-    response_class => $args->{response_class} // 'AnyEvent::Ident::Response',
+    hostname       => $args->{hostname}       || '127.0.0.1',  
+    port           => $port,
+    on_error       => $args->{on_error}       || sub { carp $_[0] },
+    response_class => $args->{response_class} || 'AnyEvent::Ident::Response',
   }, $class;
 }
 
@@ -134,13 +135,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 AnyEvent::Ident::Client - Simple asynchronous ident client
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -151,8 +154,8 @@ version 0.05
    my($res) = @_; # isa AnyEvent::Client::Response 
    if($res->is_success)
    {
-     say "user: ", $res->username;
-     say "os:   ", $res->os;
+     print "user: ", $res->username, "\n";
+     print "os:   ", $res->os, "\n";
    }
    else
    {
